==> jc-1.4.0.tar.gz: javax/swing/SpinnerListModel.h <==
// public class javax.swing.SpinnerListModel

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4b0089f574438731 javax_swing_AbstractSpinnerModel
// @dep_class 81f188b047fccc4a javax_swing_SpinnerListModel

// header file dependencies
// @dep_header javax_swing_AbstractSpinnerModel

#include "javax/swing/AbstractSpinnerModel.h"

#ifndef _JC_javax_swing_SpinnerListModel_H_
#define _JC_javax_swing_SpinnerListModel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_javax_swing_SpinnerListModel$sub_refs	_jc_javax_swing_SpinnerListModel$sub_refs;
typedef struct _jc_javax_swing_SpinnerListModel$sub_nonrefs	_jc_javax_swing_SpinnerListModel$sub_nonrefs;
typedef struct _jc_javax_swing_SpinnerListModel$refs	_jc_javax_swing_SpinnerListModel$refs;
typedef struct _jc_javax_swing_SpinnerListModel$nonrefs	_jc_javax_swing_SpinnerListModel$nonrefs;
typedef struct _jc_javax_swing_SpinnerListModel$object	_jc_javax_swing_SpinnerListModel$object;

typedef struct _jc_javax_swing_SpinnerListModel$fields_struct	_jc_javax_swing_SpinnerListModel$fields_struct;
typedef const struct _jc_javax_swing_SpinnerListModel$vmethods	_jc_javax_swing_SpinnerListModel$vmethods;
typedef const struct _jc_javax_swing_SpinnerListModel$vtable	_jc_javax_swing_SpinnerListModel$vtable;
typedef const struct _jc_javax_swing_SpinnerListModel$vtype	_jc_javax_swing_SpinnerListModel$vtype;

// Class fields structure
struct _jc_javax_swing_SpinnerListModel$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_SpinnerListModel$fields_struct _jc_javax_swing_SpinnerListModel$class_fields;

// Constructors
extern void _jc_javax_swing_SpinnerListModel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *);
extern void _jc_javax_swing_SpinnerListModel$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *, struct _jc_object *);
extern void _jc_javax_swing_SpinnerListModel$method$_init$01ab6a5208b30dec(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *, struct _jc_object_array *);

// Virtual methods
extern struct _jc_object *_jc_javax_swing_SpinnerListModel$method$getList$4cb40b6a02a7ebfe(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_swing_SpinnerListModel$method$getNextValue$3139b7ff7ffa4cdb(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_swing_SpinnerListModel$method$getPreviousValue$8e7086ed970284e8(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_swing_SpinnerListModel$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *);
extern void _jc_javax_swing_SpinnerListModel$method$setList$1ef18bfaf5bad2e0(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *, struct _jc_object *);
extern void _jc_javax_swing_SpinnerListModel$method$setValue$6db444395631b4fe(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_SpinnerListModel$method_info$getList$4cb40b6a02a7ebfe;
extern _jc_method _jc_javax_swing_SpinnerListModel$method_info$getNextValue$3139b7ff7ffa4cdb;
extern _jc_method _jc_javax_swing_SpinnerListModel$method_info$getPreviousValue$8e7086ed970284e8;
extern _jc_method _jc_javax_swing_SpinnerListModel$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_javax_swing_SpinnerListModel$method_info$setList$1ef18bfaf5bad2e0;
extern _jc_method _jc_javax_swing_SpinnerListModel$method_info$setValue$6db444395631b4fe;

// Virtual methods structure
struct _jc_javax_swing_SpinnerListModel$vmethods {
	struct _jc_object	*(*getList$4cb40b6a02a7ebfe)(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *);
	struct _jc_java_lang_Object$object	*(*getNextValue$3139b7ff7ffa4cdb)(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *);
	struct _jc_java_lang_Object$object	*(*getPreviousValue$8e7086ed970284e8)(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *);
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *);
	void	(*setList$1ef18bfaf5bad2e0)(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *, struct _jc_object *);
	void	(*setValue$6db444395631b4fe)(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_javax_swing_SpinnerListModel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractSpinnerModel$vmethods	javax_swing_AbstractSpinnerModel;
	_jc_javax_swing_SpinnerListModel$vmethods	javax_swing_SpinnerListModel;
};

// Vtype
struct _jc_javax_swing_SpinnerListModel$vtype {
	_jc_type			type;
	_jc_javax_swing_SpinnerListModel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_SpinnerListModel$sub_refs {
	struct _jc_object	*list;
};

// Reference instance fields (object)
struct _jc_javax_swing_SpinnerListModel$refs {
    _jc_javax_swing_SpinnerListModel$sub_refs	javax_swing_SpinnerListModel;
    _jc_javax_swing_AbstractSpinnerModel$sub_refs	javax_swing_AbstractSpinnerModel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_SpinnerListModel$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_SpinnerListModel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractSpinnerModel$sub_nonrefs	javax_swing_AbstractSpinnerModel;
    _jc_javax_swing_SpinnerListModel$sub_nonrefs	javax_swing_SpinnerListModel;
};

// Object instance structure
struct _jc_javax_swing_SpinnerListModel$object {
	_jc_javax_swing_SpinnerListModel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_SpinnerListModel$vtype	*vtype;
	_jc_javax_swing_SpinnerListModel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_SpinnerListModel$vtype _jc_javax_swing_SpinnerListModel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_SpinnerListModel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_SpinnerListModel$class_object;

#endif	/* _JC_javax_swing_SpinnerListModel_H_ */

==> jc-1.4.6.tar.gz: javax/swing/SpinnerListModel.h <==
// public class javax.swing.SpinnerListModel

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4b0089f574438731 javax_swing_AbstractSpinnerModel
// @dep_class 81f188b047fccc4a javax_swing_SpinnerListModel

// header file dependencies
// @dep_header javax_swing_AbstractSpinnerModel

#include "javax/swing/AbstractSpinnerModel.h"

#ifndef _JC_javax_swing_SpinnerListModel_H_
#define _JC_javax_swing_SpinnerListModel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_javax_swing_SpinnerListModel$sub_refs	_jc_javax_swing_SpinnerListModel$sub_refs;
typedef struct _jc_javax_swing_SpinnerListModel$sub_nonrefs	_jc_javax_swing_SpinnerListModel$sub_nonrefs;
typedef struct _jc_javax_swing_SpinnerListModel$refs	_jc_javax_swing_SpinnerListModel$refs;
typedef struct _jc_javax_swing_SpinnerListModel$nonrefs	_jc_javax_swing_SpinnerListModel$nonrefs;
typedef struct _jc_javax_swing_SpinnerListModel$object	_jc_javax_swing_SpinnerListModel$object;

typedef struct _jc_javax_swing_SpinnerListModel$fields_struct	_jc_javax_swing_SpinnerListModel$fields_struct;
typedef const struct _jc_javax_swing_SpinnerListModel$vmethods	_jc_javax_swing_SpinnerListModel$vmethods;
typedef const struct _jc_javax_swing_SpinnerListModel$vtable	_jc_javax_swing_SpinnerListModel$vtable;
typedef const struct _jc_javax_swing_SpinnerListModel$vtype	_jc_javax_swing_SpinnerListModel$vtype;

// Class fields structure
struct _jc_javax_swing_SpinnerListModel$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_SpinnerListModel$fields_struct _jc_javax_swing_SpinnerListModel$class_fields;

// Constructors
extern void _jc_javax_swing_SpinnerListModel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_SpinnerListModel$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_SpinnerListModel$method$_init$01ab6a5208b30dec(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_swing_SpinnerListModel$method$getList$4cb40b6a02a7ebfe(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_swing_SpinnerListModel$method$getNextValue$3139b7ff7ffa4cdb(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_swing_SpinnerListModel$method$getPreviousValue$8e7086ed970284e8(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_swing_SpinnerListModel$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_SpinnerListModel$method$setList$1ef18bfaf5bad2e0(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_SpinnerListModel$method$setValue$6db444395631b4fe(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_SpinnerListModel$method_info$getList$4cb40b6a02a7ebfe;
extern _jc_method _jc_javax_swing_SpinnerListModel$method_info$getNextValue$3139b7ff7ffa4cdb;
extern _jc_method _jc_javax_swing_SpinnerListModel$method_info$getPreviousValue$8e7086ed970284e8;
extern _jc_method _jc_javax_swing_SpinnerListModel$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_javax_swing_SpinnerListModel$method_info$setList$1ef18bfaf5bad2e0;
extern _jc_method _jc_javax_swing_SpinnerListModel$method_info$setValue$6db444395631b4fe;

// Virtual methods structure
struct _jc_javax_swing_SpinnerListModel$vmethods {
	struct _jc_object	*(*getList$4cb40b6a02a7ebfe)(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getNextValue$3139b7ff7ffa4cdb)(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getPreviousValue$8e7086ed970284e8)(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *) _JC_JCNI_ATTR;
	void	(*setList$1ef18bfaf5bad2e0)(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setValue$6db444395631b4fe)(_jc_env *, struct _jc_javax_swing_SpinnerListModel$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_SpinnerListModel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractSpinnerModel$vmethods	javax_swing_AbstractSpinnerModel;
	_jc_javax_swing_SpinnerListModel$vmethods	javax_swing_SpinnerListModel;
};

// Vtype
struct _jc_javax_swing_SpinnerListModel$vtype {
	_jc_type			type;
	_jc_javax_swing_SpinnerListModel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_SpinnerListModel$sub_refs {
	struct _jc_object	*list;
};

// Reference instance fields (object)
struct _jc_javax_swing_SpinnerListModel$refs {
    _jc_javax_swing_SpinnerListModel$sub_refs	javax_swing_SpinnerListModel;
    _jc_javax_swing_AbstractSpinnerModel$sub_refs	javax_swing_AbstractSpinnerModel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_SpinnerListModel$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_SpinnerListModel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractSpinnerModel$sub_nonrefs	javax_swing_AbstractSpinnerModel;
    _jc_javax_swing_SpinnerListModel$sub_nonrefs	javax_swing_SpinnerListModel;
};

// Object instance structure
struct _jc_javax_swing_SpinnerListModel$object {
	_jc_javax_swing_SpinnerListModel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_SpinnerListModel$vtype	*vtype;
	_jc_javax_swing_SpinnerListModel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_SpinnerListModel$vtype _jc_javax_swing_SpinnerListModel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_SpinnerListModel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_SpinnerListModel$class_object;

#endif	/* _JC_javax_swing_SpinnerListModel_H_ */
